@@ -25,6 +25,11 @@ class BertTokenTagger:
         
         inputs = self.tokenizer(line, return_tensors="pt")
         tokens =["[CLS]"] + self.tokenizer.tokenize(line) + ["[SEP]"]
+        
+        if len(tokens) > 128:
+            print("input too long")
+            return tokens, ["NONE" for t in tokens]
+
         labels = torch.tensor([1] * inputs["input_ids"].size(1)).unsqueeze(0)  # Batch size 1
         outputs = self.model(**inputs, labels=labels)
         logits = outputs.logits
